pub enum Style {
Lowpoly,
Pointillist {
noise: f32,
},
}Expand description
The visual style used to render the output image.
Variants
Lowpoly
Renders the image as a mosaic of colored triangles based on this tutorial by Samuel Hinton.
Pointillist
Renders the image as overlapping colored circles.
Fields

aurora.jpg
pointillist_0_noise.png
pointillist_100_noise.png
noise: f32noise controls the draw order of the circles. A value of 0.0 will draw smaller circles in the foreground, while
a value of 1.0 will randomly draw circles regardless of their size.
Must be in the range [0.0, 1.0].
let image = open("aurora.jpg").unwrap();
geometrize(
&image,
Style::Pointillist {noise: 0.0},
100_000,
SamplingParams::default()
).unwrap().save("pointillist_0_noise.png").unwrap();
geometrize(
&image,
Style::Pointillist {noise: 1.0},
20_000,
SamplingParams::default()
).unwrap().save("pointillist_100_noise.png").unwrap();